Class: Gcodify::Ops::DummyOp
- Inherits:
-
Gcodify::Op
- Object
- Gcodify::Op
- Gcodify::Ops::DummyOp
- Defined in:
- lib/gcodify/ops/dummyop.rb
Overview
A passthrough Gcodify::Op for testing purposes. It contains @str which is the string passed during initialization, which will be returned by #to_gcode.
Instance Attribute Summary
Attributes inherited from Gcodify::Op
Instance Method Summary collapse
-
#initialize(str) ⇒ DummyOp
constructor
A new instance of DummyOp.
-
#to_gcode ⇒ String
Returns the string that was passed in when initted.
Constructor Details
#initialize(str) ⇒ DummyOp
Returns a new instance of DummyOp.
9 10 11 |
# File 'lib/gcodify/ops/dummyop.rb', line 9 def initialize(str) @str = str end |
Instance Method Details
#to_gcode ⇒ String
Returns the string that was passed in when initted.
16 17 18 |
# File 'lib/gcodify/ops/dummyop.rb', line 16 def to_gcode @str end |